# Laurent Tupin - pynut

It provides various functions to provide additionnal functionnalities
For more information see the tutorial ...

## Installation

You can install the package from [PyPI](https://pypi.org/project/pynut/):
    python -m pip install pynut
The package is supported on Python 3.7 and above.

## How to use

    $ ...
    


You can call a function like this example:

    >>> from pyNut import nutDate
    >>> nutDate.today()
  
It is preferable you have those versions of the libraries

    >>> beautifulsoup4==4.7.1
    >>> exchangelib==4.7.2
    >>> openpyxl==3.0.5
    >>> pandas==1.1.3
    >>> paramiko==2.6.0
    >>> psutil==5.9.0
    >>> pyodbc==4.0.32
    >>> PyQt5==5.15.1
    >>> pywin32==303
    >>> selenium==3.141.0
    >>> xlrd==1.2.0
    >>> XlsxWriter==1.3.5
    >>> xlwings==0.20.8

